@@ -15,8 +15,8 @@ sub throwException {
     if (defined($exception_command->{payload}[4])){
         $stack_trace = create_stack_trace($exception_command->{payload}[4], $exception_command->{payload}[5], $exception_command->{payload}[6], $exception_command->{payload}[7]);
     }
-
-    die $exception_name . " \n " . $exception_message . " \n " .$stack_trace;
+    my $exception_msg = $exception_name . " \n " . $exception_message . " \n " .$stack_trace;
+    die $exception_msg;
 }
 
 sub create_stack_trace {
