@@ -1,13 +1,9 @@
 package Javonet::Core::Handler::CommandHandler::DestructReferenceHandler;
-use aliased 'Javonet::Core::Handler::PerlHandler' => 'PerlHandler';
 use strict;
 use warnings FATAL => 'all';
+use lib 'lib';
 use Moose;
 use Nice::Try;
-use Data::Dumper;
-use lib 'lib';
-use lib 'data_seed';
-
 use aliased 'Javonet::Core::Exception::Exception' => 'Exception';
 extends 'Javonet::Core::Handler::CommandHandler::AbstractCommandHandler';
 
